/*****************************************************************
 *****************************************************************
 ***                                                            **
 ***    (C)Copyright 2005-2006, American Megatrends Inc.        **
 ***                                                            **
 ***            All Rights Reserved.                            **
 ***                                                            **
 ***        6145-F, Northbelt Parkway, Norcross,                **
 ***                                                            **
 ***        Georgia - 30071, USA. Phone-(770)-246-8600.         **
 ***                                                            **
 *****************************************************************
 ******************************************************************
 * 
 * Firewall.h
 * IPMI firmware firewall commands
 *
 *  Author: Ravinder Reddy <bakkar@ami.com>
 *          Basavaraj Astekar <basavaraja@ami.com>
 *          
 ******************************************************************/
#ifndef FIREWALL_H
#define FIREWALL_H
#include "com_BmcType.h"
#include "com_IPMIDefs.h"

#pragma pack(1)
typedef struct{
  uint8_t IANA[3];
} IANA_T;
#pragma pack()
/*** Function Prototypes ***/

// /**
//  * @defgroup apcf5 Firmware Firewall Commands
//  * @ingroup apcf
//  * IPMI IPM Device Command Handlers. Invoked by the message handler
//  * (IPMI 2.0 feature)
//  * @{
//  **/
// extern int GetNetFnSup      ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetCmdSup        ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetSubFnSup      ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetConfigCmds    ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetConfigSubFns  ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int SetCmdEnables    ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetCmdEnables    ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int SetSubFnEnables  ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetSubFnEnables  ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// extern int GetOEMNetFnIANASupport  ( uint8_t* pReq, uint8_t ReqLen,  uint8_t* pRes);
// /** @} */

#endif /* FIREWALL_H */
